/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EOS = 258,
     COMMA = 259,
     LEFT_SQ_BRACKET = 260,
     RIGHT_SQ_BRACKET = 261,
     LEFT_PAREN = 262,
     RIGHT_PAREN = 263,
     WILD = 264,
     TOK_COLLECTOR = 265,
     TOK_EXPORTER = 266,
     TOK_DNS_DEDUP = 267,
     TOK_DNSDEDUP_ONLY = 268,
     TOK_NO_STATS = 269,
     TOK_PORT = 270,
     TOK_HOST = 271,
     TOK_PATH = 272,
     TOK_DAEMON = 273,
     TOK_DELIM = 274,
     TOK_PRINT_HDR = 275,
     TOK_GROUP = 276,
     TOK_MOVE = 277,
     TOK_DELETE = 278,
     TOK_LOCK = 279,
     TOK_UDP_TIMEOUT = 280,
     TOK_ROTATE = 281,
     TOK_END = 282,
     TOK_FILTER = 283,
     TOK_LOG_FILE = 284,
     TOK_FLOW_ONLY = 285,
     TOK_DPI_ONLY = 286,
     TOK_POLL = 287,
     TOK_MAX_HIT = 288,
     TOK_FLUSH_TIMEOUT = 289,
     TOK_LOG_LEVEL = 290,
     TOK_BASE_64 = 291,
     TOK_LAST_SEEN = 292,
     TOK_RM_EMPTY = 293,
     TOK_STATS_ONLY = 294,
     TOK_TABLE = 295,
     TOK_DPI_CONFIG = 296,
     TOK_MULTI_FILES = 297,
     TOK_NO_INDEX = 298,
     TOK_TIMESTAMP_FILES = 299,
     TOK_NO_FLOW_STATS = 300,
     TOK_PID_FILE = 301,
     TOK_MY_REMOVE = 302,
     TOK_MY_USER = 303,
     TOK_MY_PW = 304,
     TOK_MY_DB = 305,
     TOK_MY_HOST = 306,
     TOK_MY_TABLE = 307,
     TOK_FIELDS = 308,
     TOK_DPI_FIELD_LIST = 309,
     TOK_DPI_DELIMITER = 310,
     TOK_STATS_TIMEOUT = 311,
     TOK_USERIE = 312,
     TOK_AND_FILTER = 313,
     TOK_ESCAPE = 314,
     TOK_DNSRR_ONLY = 315,
     TOK_FULL = 316,
     TOK_LOG_DIR = 317,
     TOK_JSON = 318,
     TOK_RECORDS = 319,
     TOK_RESP_ONLY = 320,
     TOK_SSL_CONFIG = 321,
     TOK_ISSUER = 322,
     TOK_SUBJECT = 323,
     TOK_OTHER = 324,
     TOK_EXTENSIONS = 325,
     TOK_DEDUP_PER_FLOW = 326,
     TOK_DEDUP_CONFIG = 327,
     TOK_FILE = 328,
     TOK_MERGE = 329,
     TOK_SSL_DEDUP = 330,
     TOK_CERT_FILE = 331,
     TOK_SSL_DEDUP_ONLY = 332,
     TOK_MD5 = 333,
     TOK_SHA1 = 334,
     TOK_GZIP = 335,
     TOK_DNSRR = 336,
     TOK_DEDUP_ONLY = 337,
     TOK_NO_FLOW = 338,
     TOK_OBID_MAP = 339,
     TOK_VLAN_MAP = 340,
     TOK_MAP = 341,
     TOK_DISCARD = 342,
     TOK_ADD_EXPORTER_NAME = 343,
     TOK_DECOMPRESS = 344,
     TOK_METADATA_EXPORT = 345,
     TOK_GEN_TOMBSTONE = 346,
     TOK_TOMBSTONE_CONFIGURED_ID = 347,
     TOK_TOMBSTONE_CONFIG = 348,
     TOK_PRESERVE_OBDOMAIN = 349,
     TOK_REWRITE_SSL_CERTS = 350,
     TOK_PREFIX_MAP = 351,
     TOK_MATCHES_IPSET = 352,
     TOK_SILKCONFIG_CONFIG = 353,
     TOK_SILKCONFIG_PROBE = 354,
     TOK_SILKCONFIG_SENSOR = 355,
     TOK_SILKCONFIG_SILK = 356,
     TOK_TIME_UNITS = 357,
     TOK_ROTATE_MAX_SIZE = 358,
     TOK_ROTATE_MIN_SIZE = 359,
     VAL_ATOM = 360,
     VAL_DATETIME = 361,
     VAL_DOUBLE = 362,
     VAL_HEXADECIMAL = 363,
     VAL_INTEGER = 364,
     VAL_IP = 365,
     VAL_QSTRING = 366,
     VAL_TRANSPORT = 367,
     VAL_OPER = 368,
     VAL_FIELD = 369,
     VAL_LOGLEVEL = 370,
     VAL_TIMEUNIT = 371
   };
#endif
/* Tokens.  */
#define EOS 258
#define COMMA 259
#define LEFT_SQ_BRACKET 260
#define RIGHT_SQ_BRACKET 261
#define LEFT_PAREN 262
#define RIGHT_PAREN 263
#define WILD 264
#define TOK_COLLECTOR 265
#define TOK_EXPORTER 266
#define TOK_DNS_DEDUP 267
#define TOK_DNSDEDUP_ONLY 268
#define TOK_NO_STATS 269
#define TOK_PORT 270
#define TOK_HOST 271
#define TOK_PATH 272
#define TOK_DAEMON 273
#define TOK_DELIM 274
#define TOK_PRINT_HDR 275
#define TOK_GROUP 276
#define TOK_MOVE 277
#define TOK_DELETE 278
#define TOK_LOCK 279
#define TOK_UDP_TIMEOUT 280
#define TOK_ROTATE 281
#define TOK_END 282
#define TOK_FILTER 283
#define TOK_LOG_FILE 284
#define TOK_FLOW_ONLY 285
#define TOK_DPI_ONLY 286
#define TOK_POLL 287
#define TOK_MAX_HIT 288
#define TOK_FLUSH_TIMEOUT 289
#define TOK_LOG_LEVEL 290
#define TOK_BASE_64 291
#define TOK_LAST_SEEN 292
#define TOK_RM_EMPTY 293
#define TOK_STATS_ONLY 294
#define TOK_TABLE 295
#define TOK_DPI_CONFIG 296
#define TOK_MULTI_FILES 297
#define TOK_NO_INDEX 298
#define TOK_TIMESTAMP_FILES 299
#define TOK_NO_FLOW_STATS 300
#define TOK_PID_FILE 301
#define TOK_MY_REMOVE 302
#define TOK_MY_USER 303
#define TOK_MY_PW 304
#define TOK_MY_DB 305
#define TOK_MY_HOST 306
#define TOK_MY_TABLE 307
#define TOK_FIELDS 308
#define TOK_DPI_FIELD_LIST 309
#define TOK_DPI_DELIMITER 310
#define TOK_STATS_TIMEOUT 311
#define TOK_USERIE 312
#define TOK_AND_FILTER 313
#define TOK_ESCAPE 314
#define TOK_DNSRR_ONLY 315
#define TOK_FULL 316
#define TOK_LOG_DIR 317
#define TOK_JSON 318
#define TOK_RECORDS 319
#define TOK_RESP_ONLY 320
#define TOK_SSL_CONFIG 321
#define TOK_ISSUER 322
#define TOK_SUBJECT 323
#define TOK_OTHER 324
#define TOK_EXTENSIONS 325
#define TOK_DEDUP_PER_FLOW 326
#define TOK_DEDUP_CONFIG 327
#define TOK_FILE 328
#define TOK_MERGE 329
#define TOK_SSL_DEDUP 330
#define TOK_CERT_FILE 331
#define TOK_SSL_DEDUP_ONLY 332
#define TOK_MD5 333
#define TOK_SHA1 334
#define TOK_GZIP 335
#define TOK_DNSRR 336
#define TOK_DEDUP_ONLY 337
#define TOK_NO_FLOW 338
#define TOK_OBID_MAP 339
#define TOK_VLAN_MAP 340
#define TOK_MAP 341
#define TOK_DISCARD 342
#define TOK_ADD_EXPORTER_NAME 343
#define TOK_DECOMPRESS 344
#define TOK_METADATA_EXPORT 345
#define TOK_GEN_TOMBSTONE 346
#define TOK_TOMBSTONE_CONFIGURED_ID 347
#define TOK_TOMBSTONE_CONFIG 348
#define TOK_PRESERVE_OBDOMAIN 349
#define TOK_REWRITE_SSL_CERTS 350
#define TOK_PREFIX_MAP 351
#define TOK_MATCHES_IPSET 352
#define TOK_SILKCONFIG_CONFIG 353
#define TOK_SILKCONFIG_PROBE 354
#define TOK_SILKCONFIG_SENSOR 355
#define TOK_SILKCONFIG_SILK 356
#define TOK_TIME_UNITS 357
#define TOK_ROTATE_MAX_SIZE 358
#define TOK_ROTATE_MIN_SIZE 359
#define VAL_ATOM 360
#define VAL_DATETIME 361
#define VAL_DOUBLE 362
#define VAL_HEXADECIMAL 363
#define VAL_INTEGER 364
#define VAL_IP 365
#define VAL_QSTRING 366
#define VAL_TRANSPORT 367
#define VAL_OPER 368
#define VAL_FIELD 369
#define VAL_LOGLEVEL 370
#define VAL_TIMEUNIT 371




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 409 "mediator_config_parse.y"
{
    char                   *str;
    int                     integer;
    smFieldMap_t           *fieldMap;
    mdParserNumber_t        *number;
    mdTransportType_t       transport;
    mdAcceptFilterField_t   field;
    fieldOperator           oper;
    mdLogLevel_t            log_level;
    mdTimeUnits_t           timeUnit;
}
/* Line 1529 of yacc.c.  */
#line 293 "mediator_config_parse.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

